mustgather

package
v0.0.0-...-45e41bb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 8, 2025 License: Apache-2.0 Imports: 27 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand(logger *logger.FunLogger) *cli.Command

NewCommand constructs a must-gather command with the specified logger

Types

type CopyOptions

type CopyOptions struct {
	Container  string
	Namespace  string
	NoPreserve bool
	MaxTries   int

	ClientConfig      *restclient.Config
	Clientset         kubernetes.Interface
	ExecParentCmdName string

	genericiooptions.IOStreams
}

CopyOptions have the data required to perform the copy operation

func NewCopyOptions

func NewCopyOptions(ioStreams genericiooptions.IOStreams) *CopyOptions

NewCopyOptions creates the options for copy

type Gatherer

type Gatherer struct {
	// contains filtered or unexported fields
}

Gatherer holds all the initialized resources needed for must-gather operations.

func NewGatherer

func NewGatherer(opts *Options) (*Gatherer, error)

NewGatherer initializes a new Gatherer by performing the following tasks: 1. Create the artifact directory. 2. Create log files for stdout and stderr. 3. Build the Kubernetes REST config and apply default settings. 4. Create the Kubernetes clientset. If any step fails, any opened file resources are closed before returning.

func (*Gatherer) Close

func (g *Gatherer) Close()

Close releases any resources held by the Gatherer.

type Options

type Options struct {
	ArtifactDir string // Directory to store gathered artifacts/logs.
	Kubeconfig  string // Path to the Kubernetes configuration file.
}

Options defines the configurable parameters for the must-gather operation.

type PodInfo

type PodInfo struct {
	OperandPods  *v1.PodList
	OperatorPods *v1.PodList
}

PodInfo groups the GPU operand pods and operator pods retrieved from the cluster.

type TarPipe

type TarPipe struct {
	// contains filtered or unexported fields
}

func (*TarPipe) Read

func (t *TarPipe) Read(p []byte) (n int, err error)

Jump to