Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CopyOptions ¶
type CopyOptions struct {
Container string
Namespace string
NoPreserve bool
MaxTries int
ClientConfig *restclient.Config
Clientset kubernetes.Interface
ExecParentCmdName string
genericiooptions.IOStreams
}
CopyOptions have the data required to perform the copy operation
func NewCopyOptions ¶
func NewCopyOptions(ioStreams genericiooptions.IOStreams) *CopyOptions
NewCopyOptions creates the options for copy
type Gatherer ¶
type Gatherer struct {
// contains filtered or unexported fields
}
Gatherer holds all the initialized resources needed for must-gather operations.
func NewGatherer ¶
NewGatherer initializes a new Gatherer by performing the following tasks: 1. Create the artifact directory. 2. Create log files for stdout and stderr. 3. Build the Kubernetes REST config and apply default settings. 4. Create the Kubernetes clientset. If any step fails, any opened file resources are closed before returning.
type Options ¶
type Options struct {
ArtifactDir string // Directory to store gathered artifacts/logs.
Kubeconfig string // Path to the Kubernetes configuration file.
}
Options defines the configurable parameters for the must-gather operation.
Click to show internal directories.
Click to hide internal directories.